GenericHkdf

Struct GenericHkdf 

pub struct GenericHkdf<H: HmacImpl> {
    pub(crate) hmac: H,
}
Structure representing the HKDF, capable of HKDF-Expand and HKDF-Extract operations. Recommendations for the correct usage of the parameters can be found in the crate root.

This type is generic over HMAC implementation. Most users should use Hkdf or SimpleHkdf type aliases.

Fields

hmac: H

Implementations

Source

impl<H: HmacImpl> GenericHkdf<H>

pub fn new(salt: Option<&[u8]>, ikm: &[u8]) -> Self

Convenience method for extract when the generated pseudorandom key can be ignored and only HKDF-Expand operation is needed. This is the most common constructor.

pub fn from_prk(prk: &[u8]) -> Result<Self, InvalidPrkLength>

Create Hkdf from an already cryptographically strong pseudorandom key as per section 3.3 from RFC5869.

Errors

Returns InvalidPrkLength if prk is shorter than the output size of H.

pub fn extract(salt: Option<&[u8]>, ikm: &[u8]) -> (Output<H>, Self)

The RFC5869 HKDF-Extract operation returning both the generated pseudorandom key and Hkdf struct for expanding.

pub fn expand_multi_info( &self, info_components: &[&[u8]], okm: &mut [u8], ) -> Result<(), InvalidLength>

The RFC5869 HKDF-Expand operation. This is equivalent to calling expand with the info argument set equal to the concatenation of all the elements of info_components.

Errors

Returns InvalidLength in the event okm is too large.

pub fn expand(&self, info: &[u8], okm: &mut [u8]) -> Result<(), InvalidLength>

The RFC5869 HKDF-Expand operation

If you don’t have any info to pass, use an empty slice.

Errors

Returns InvalidLength in the event okm is too large.