GenericHkdfExtract

Struct GenericHkdfExtract 

pub struct GenericHkdfExtract<H: HmacImpl> {
    pub(crate) hmac: H,
}
Structure representing the streaming context of an HKDF-Extract operation.

This type is generic over HMAC implementation. Most users should use HkdfExtract or SimpleHkdfExtract type aliases.

Fields

hmac: H

Implementations

Source

impl<H: HmacImpl> GenericHkdfExtract<H>

pub fn new(salt: Option<&[u8]>) -> Self

Initiates the HKDF-Extract context with the given optional salt

pub fn input_ikm(&mut self, ikm: &[u8])

Feeds in additional input key material to the HKDF-Extract context

pub fn finalize(self) -> (Output<H>, GenericHkdf<H>)

Completes the HKDF-Extract operation, returning both the generated pseudorandom key and Hkdf struct for expanding.