pub type Hkdf<H> = GenericHkdf<Hmac<H>>;Expand description
GenericHkdf variant which uses Hmac for the underlying HMAC implementation.
Aliased Type
pub struct Hkdf<H> {
pub(crate) hmac: Hmac<H>,
}Fields
hmac: Hmac<H>pub type Hkdf<H> = GenericHkdf<Hmac<H>>;GenericHkdf variant which uses Hmac for the underlying HMAC implementation.
pub struct Hkdf<H> {
pub(crate) hmac: Hmac<H>,
}hmac: Hmac<H>